Index: test/mjsunit/regress/regress-function-constructor-receiver.js |
diff --git a/test/mjsunit/regress/regress-function-constructor-receiver.js b/test/mjsunit/regress/regress-function-constructor-receiver.js |
index f345435ade0d72063307bf49267e9f11513ce42d..5d713803bef1ff93e99f20fd0510933df43a826f 100644 |
--- a/test/mjsunit/regress/regress-function-constructor-receiver.js |
+++ b/test/mjsunit/regress/regress-function-constructor-receiver.js |
@@ -10,8 +10,8 @@ try { |
new Function({toString:0,valueOf:0}); |
} catch (e) { |
threw = true; |
- // Ensure that the receiver during "new Function" is the global proxy. |
- assertEquals(this, e.stack[0].getThis()); |
+ // Ensure that the receiver during "new Function" is the undefined value. |
+ assertEquals(undefined, e.stack[0].getThis()); |
} |
assertTrue(threw); |